@@ -101,7 +101,9 @@ BINS_LIST=['hpijs','hp-align','hp-colorcal','hp-faxsetup','hp-linefeedcal','hp-p
 
 LIBS_LIST=['libhpmud.*','libhpip.*','sane/libsane-hpaio.*','cups/backend/hp','cups/backend/hpfax', 'cups/filter/hpcac', 'cups/filter/hpps', 'cups/filter/pstotiff','cups/filter/hpcups', 'cups/filter/hpcupsfax', 'cups/filter/hplipjs']
 
-FILES_LIST=['/etc/udev/rules.d/56-hpmud_support.rules', '/etc/udev/rules.d/40-hplip.rules', '/etc/udev/rules.d/56-hpmud_support.rules', '/etc/udev/rules.d/55-hpmud.rules','/etc/udev/rules.d/56-hpmud_add_printer.rules','/etc/udev/rules.d/55-hpmud_sysfs.rules','/etc/udev/rules.d/56-hpmud_add_printer_sysfs.rules', '/etc/udev/rules.d/56-hpmud_support_sysfs.rules', '/etc/udev/rules.d/86-hpmud_plugin_sysfs.rules', '/etc/udev/rules.d/86-hpmud-hp_*.rules', '/etc/udev/rules.d/86-hpmud_plugin.rules', '/usr/share/cups/drv/hp/','/usr/local/share/ppd/HP/','/usr/local/share/cups/drv/hp/' ,'/usr/share/applications/hplip.desktop', '/etc/xdg/autostart/hplip-systray.desktop', '/etc/hp/hplip.conf', '/usr/share/doc/hplip-*']
+FILES_LIST=[ '/usr/share/cups/drv/hp/','/usr/local/share/ppd/HP/','/usr/local/share/cups/drv/hp/' ,'/usr/share/applications/hplip.desktop', '/etc/xdg/autostart/hplip-systray.desktop', '/etc/hp/hplip.conf', '/usr/share/doc/hplip-*','/usr/lib/systemd/system/hplip-printer*.service']
+
+RULES_LIST=['56-hpmud.rules','56-hpmud_sysfs.rules', '40-hplip.rules', '56-hpmud_support.rules', '56-hpmud_support_sysfs.rules','55-hpmud.rules','55-hpmud_sysfs.rules','56-hpmud_add_printer.rules','56-hpmud_add_printer_sysfs.rules', '86-hpmud-hp_*.rules', '86-hpmud_plugin.rules', '86-hpmud_plugin_sysfs.rules']
 
 HPLIP_LIST=['*.py','*.pyc', 'base', 'copier','data','installer','pcard','ui4','ui','fax/*.py','fax/*.pyc','fax/pstotiff.convs','fax/pstotiff.types','fax/pstotiff','prnt/*.py', 'prnt/*.pyc', 'scan/*.py','scan/*.pyc']
 
@@ -322,7 +324,8 @@ class CoreInstall(object):
             'libnetsnmp-devel': (True,  ['network'], "libnetsnmp-devel - SNMP networking library development files", self.check_libnetsnmp, DEPENDENCY_RUN_AND_COMPILE_TIME),
             'libcrypto':        (True,  ['network'], "libcrypto - OpenSSL cryptographic library", self.check_libcrypto, DEPENDENCY_RUN_AND_COMPILE_TIME),
             'network':        (False, ['network'], "network -wget", self.check_wget, DEPENDENCY_RUN_TIME),
-
+            'avahi-utils':        (False, ['network'], "avahi-utils", self.check_avahi_utils, DEPENDENCY_RUN_TIME),
+            'passwd_util':        (False, ['gui_qt4'], "GUI Password utility (gksu/kdesu)", self.check_passwd_util, DEPENDENCY_RUN_TIME),
         }
 
         for opt in self.options:
@@ -965,7 +968,7 @@ class CoreInstall(object):
     def check_pil(self):
         log.debug("Checking for PIL...")
         try:
-            import Image
+            from PIL import Image
             return True
         except ImportError:
             return False
@@ -1496,6 +1499,23 @@ class CoreInstall(object):
             log.debug("wget is not installed")
             return False
 
+    def check_avahi_utils(self):
+        if utils.which("avahi-browse"):
+            return True
+        else:
+            log.debug("avahi-browse is not installed")
+            return False
+        
+    def check_passwd_util(self):
+        if utils.which("gksu"):
+            return True
+        elif utils.which("kdesu"):
+            return True
+        elif utils.which("kdesudo"):
+            return True
+        else:
+            log.debug("GUI password gksu/kdesu/kdesudo utility is not installed")
+            return False
 
 
     def run_pre_install(self, callback=None,distro_ver=None):
@@ -1672,7 +1692,11 @@ class CoreInstall(object):
     def is_auto_installer_support(self, distro_version = DISTRO_VER_UNKNOWN):
         if not self.distro_name:
             self.get_distro()
-            self.distro_name = self.distros_index[self.distro]
+            try:
+                self.distro_name = self.distros_index[self.distro]
+            except KeyError:
+                log.debug("Auto installation is not supported as Distro Name can't find for distro index [%d]."%(self.distro))
+                return False
 
         if distro_version == DISTRO_VER_UNKNOWN:
             distro_version = self.distro_version
@@ -1809,6 +1833,15 @@ class CoreInstall(object):
             utils.remove(FILES_LIST_FULL[cnt], self.passwordObj, checkSudo)
             cnt += 1
 
+        # removing Rules files
+        RULES_LIST_FULL = utils.expandList(RULES_LIST, '/etc/udev/rules.d')
+        for fl in RULES_LIST_FULL:
+            utils.remove(fl, self.passwordObj, checkSudo)
+
+        RULES_LIST_FULL = utils.expandList(RULES_LIST, '/lib/udev/rules.d')
+        for fl in RULES_LIST_FULL:
+            utils.remove(fl , self.passwordObj, checkSudo)
+
         # removing Plug-in files
         if remove_plugins == True:
             cnt =0
