@@ -42,6 +42,7 @@
 #include "ijs_server.h"
 #include "hpijs.h"
 #include "services.h"
+#include "utils.h"
 
 extern void SendDbusMessage (const char *dev, const char *printer, int code, 
                              const char *username, const int jobid, const char *title);
@@ -96,9 +97,11 @@ void setLogLevel(UXServices *pSS)
 
     if (pSS->m_iLogLevel & SAVE_PCL_FILE)
     {
-        char    szFileName[32];
-	sprintf (szFileName, "/tmp/hpijs_%d.out", getpid());
-	pSS->outfp = fopen (szFileName, "w");
+        char    szFileName[64];
+        snprintf (szFileName,sizeof(szFileName), "/var/log/hp/tmp/hpijs_%d_XXXXXX", getpid());
+        createTempFile(szFileName, &pSS->outfp);
+
+//	pSS->outfp = fopen (szFileName, "w");
 	if (pSS->outfp)
 	{
 	    chmod (szFileName, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
@@ -433,7 +436,7 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
    {
        fY = pSS->pPC->PrintableHeight ();
       /* If duplexing, adjust printable height to 1/2 inch top/bottom margins, except laserjets. */
-      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
+      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage() && (FALSE == pSS->pPC->IsBorderless()))
       {
           // User has requested fullbleed printing and printer supports 4-sided fullbleed or
           // top and bottom margin are equal (0.125"), then
@@ -473,7 +476,7 @@ int hpijs_get_cb(void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id, const ch
    {
        fY = pSS->pPC->PrintableStartY (); 
       /* If duplexing, adjust printable top to 1/2 inch top margin, except laserjets. */
-      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage())
+      if ((pSS->pPC->QueryDuplexMode() != DUPLEXMODE_NONE) && pSS->pPC->RotateImageForBackPage() && (FALSE == pSS->pPC->IsBorderless()))
       {
 #if 0
          if ((pSS->pPC->PrintableHeight () + 0.28) < pSS->pPC->PhysicalPageSizeY ())
@@ -625,7 +628,9 @@ int main (int argc, char *argv[], char *evenp[])
    setLogLevel(pSS);
 
 #ifdef CAPTURE
-   if ((pSS->InitScript("/tmp/capout", TRUE)) != NO_ERROR)
+   char szCapOutFile[64];
+   snprintf(szCapOutFile, sizeof(szCapOutFile),"%s/capout_XXXXXX","/var/log/hp/tmp");
+   if ((pSS->InitScript(szCapOutFile, TRUE)) != NO_ERROR)
       BUG("unable to init capture");
 #endif
 
