@@ -75,6 +75,7 @@ BLIP_DELAY = 2000
 SET_MENU_DELAY = 1000
 MAX_MENU_EVENTS = 10
 UPGRADE_CHECK_DELAY=24*60*60*1000 		#1 day
+CLEAN_EXEC_DELAY=4*60*60*1000 		#4 Hrs
 
 ERROR_STATE_TO_ICON = {
     ERROR_STATE_CLEAR:        QSystemTrayIcon.Information,
@@ -351,9 +352,17 @@ class SystemTrayApp(QApplication):
 
         QTimer.singleShot(SET_MENU_DELAY, self.initDone)
 
-        self.timer = QTimer()
-        self.timer.connect(self.timer,SIGNAL("timeout()"),self.handle_hplip_updation)
-        self.timer.start(UPGRADE_CHECK_DELAY)
+        self.update_timer = QTimer()
+        self.update_timer.connect(self.update_timer,SIGNAL("timeout()"),self.handle_hplip_updation)
+        self.update_timer.start(UPGRADE_CHECK_DELAY)
+
+        # Cleans the /var/log/hp/tmp directory
+        self.handle_hplip_clean()
+        
+        self.clean_timer = QTimer()
+        self.clean_timer.connect(self.clean_timer,SIGNAL("timeout()"),self.handle_hplip_clean)
+        self.clean_timer.start(CLEAN_EXEC_DELAY)
+        
 
 
 
@@ -374,6 +383,12 @@ class SystemTrayApp(QApplication):
         else:
             devices[device_uri].needs_update = True
 
+    def handle_hplip_clean(self):
+        log.debug("handle_hplip_clean ")
+        home_dir = sys_conf.get('dirs', 'home')
+        cmd = 'sh %s/hplip_clean.sh'%home_dir
+        os.system(cmd)
+        
 
     def handle_hplip_updation(self):
         log.debug("handle_hplip_updation upgrade_notify =%d"%(self.user_settings.upgrade_notify))
@@ -451,7 +466,7 @@ class SystemTrayApp(QApplication):
                     try:
                         self.service = self.session_bus.get_object('com.hplip.StatusService',
                                                                   "/com/hplip/StatusService")
-                    except DBusException:
+                    except dbus.DBusException:
                         log.warn("Unable to connect to StatusService. Retrying...")
 
                     t += 1
@@ -764,7 +779,10 @@ class SystemTrayApp(QApplication):
                                     else:
                                         n.set_timeout(TRAY_MESSAGE_DELAY)
 
-                                    n.show()
+                                    try:
+                                        n.show()
+                                    except:
+                                        log.error("Failed to show notification!")
 
                                 else: # Use "standard" message bubbles
                                     icon = ERROR_STATE_TO_ICON.get(error_state, QSystemTrayIcon.Information)
@@ -805,7 +823,13 @@ def run(read_pipe):
     log.set_module("hp-systray(qt4)")
     log.debug("PID=%d" % os.getpid())
 
-    app = SystemTrayApp(sys.argv, read_pipe)
+    try:
+        app = SystemTrayApp(sys.argv, read_pipe)
+    except dbus.DBusException, e:
+        # No session bus
+        log.debug("Caught exception: %s" % e)
+        sys.exit(1)
+
     app.setQuitOnLastWindowClosed(False) # If not set, settings dlg closes app
 
     i = 0
